

//Standard New Keynesian Model (SNKMo
//Phaneuf and Victor
//August 2018



/*
 * Copyright (C) 2010 Dynare Team
 *
 * This file is part of Dynare.
 *
 * Dynare is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Dynare is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 */


var c L y w infl pr int mc s lam x1 x2 A utc utn Vc Vn V;

% MU of consumption; consumption; return on capital; utilization; multiplier on accumulation;
% investment; interest rate; inflation; reset wage; auxiliary variables f1 and f2;
% capital services; real marginal cost; price dispersion; gross output; labor;
% intermediate inputs; reset price; auxiliary variables x1 and x2; wage;
% output; capital; intertemporal preference shock; intratemporal preference shock;
% productivity; monetary shock; investment-specific shock

varexo uA ur;

% shock to intertemporal preference; intratemporal preference; productivity; monetary policy; investment-specific

parameters beta pistar chi eta theta xip gammap alphapi alphay rhoi rhoA rhor suA sur ints ys lams ls ws ps x1s x2s mcs ss As css;

% discount factor; habit formation; utilization cost; investment adjustment cost;

% discount factor; habit formation; utilization cost; investment adjustment cost;
% depreciation; inflation target; elasticity of sub labor; inverse Frisch; labor disutility;
% calvo wages; indexation wages; capital share; intermediate share; fixed cost;
% elasticity of sub goods; calvo prices; indexation prices; TR inflation; 
% TR output; TR smoothing; AR shocks; SD shocks; ss interest rate; ss output 

load parameter_SNKM;

set_param_value('beta',beta);
set_param_value('pistar',pistar);
set_param_value('chi',chi);
set_param_value('eta',eta);
set_param_value('theta',theta);
set_param_value('xip',xip);
set_param_value('gammap',gammap);
set_param_value('alphapi',alphapi);
set_param_value('alphay',alphay);
set_param_value('rhoi',rhoi);
set_param_value('rhoA',rhoA);
set_param_value('rhor',rhor);
set_param_value('suA',suA);
set_param_value('sur',sur);
set_param_value('ints',ints);
set_param_value('ys',ys);
set_param_value('lams',lams);
set_param_value('ls',ls);
set_param_value('ws',ws);
set_param_value('ps',ps);
set_param_value('x1s',x1s);
set_param_value('x2s',x2s);
set_param_value('mcs',mcs);
set_param_value('ss',ss);
set_param_value('As',As);
set_param_value('css',css);


model;

%%Houselolds
% (1) marginal utility of consumption
exp(lam) = 1/exp(c);

% (2) bonds FOC
exp(lam) = beta*(1+int)*exp(infl(+1))^(-1)*exp(lam(+1));

% (3) Choice of labor
eta*exp(L)=exp(lam)*exp(w);

% (4) Choice of labor
exp(w)=exp(mc)*exp(A);

%Firms
% (5) Reset price
exp(pr) = (theta/(theta-1))*(exp(x1)/exp(x2));

% (6) Auxiliary x1
exp(x1) = exp(lam)*exp(mc)*exp(y) + xip*beta*(exp(infl)^(gammap)/exp(infl(+1)))^(-theta)*exp(x1(+1));

% (7 ) Auxiliary x2
exp(x2) = exp(lam)*exp(y) + xip*beta*(exp(infl)^(gammap)/exp(infl(+1)))^(1-theta)*exp(x2(+1));

%8
exp(y)=exp(c);

% ( 9) Price evolution
1 = xip*(exp(infl(-1))^(gammap)/exp(infl))^(1-theta) + (1-xip)*exp(pr)^(1-theta);

% (10)Production function
exp(s)*exp(y) = exp(A)*exp(L);


% (11) Price dispersion
exp(s) = (1-xip)*exp(pr)^(-theta) + xip*(exp(infl(-1))^(gammap)/exp(infl))^(-theta)*exp(s(-1));

% (12) Productivity shock
((1+int)/(1+ints)) = ((exp(infl)/pistar)^(alphapi)*(exp(y)/exp(y(-1)))^(alphay))^(1-rhoi)*((1+int(-1))/(1+ints))^(rhoi)*exp(ur);

% (13) Productivity shock
exp(A) = exp(A(-1))^(rhoA)*As^(1-rhoA)*exp(uA);

% (30) Utility from consumption
utc = log(exp(c));

% (31) Utility from labor
utn = -eta*(exp(L)^(1+chi)/(1+chi));

% (32) Welfare from consumption
Vc = utc + beta*Vc(+1);

% (33) Welfare from labor
Vn = utn + beta*Vn(+1);

% (34) Total welfare
V = Vc + Vn;

end;

initval;
A = log(As);
y = log(ys);
int = ints;
lam = log(lams);
L = log(ls);
w = log(ws);
pr = log(ps);
x1 = log(x1s);
x2 = log(x2s);
infl = log(pistar);
c = log(css);
mc = log(mcs);
s = log(ss);

utc = log(css);
utn = -eta*(ls^(1+chi)/(1+chi));
Vn = (1/(1-beta))*(-eta*(ls^(1+chi)/(1+chi)));
Vc = (1/(1-beta))*log(css);
end;

steady;

shocks;

var uA = suA^2;
var ur = sur^2;
end;

stoch_simul(order=2,irf=100,pruning,nograph);
%stoch_simul(order=2,irf=20,pruning,nograph);