
//Baseline model deterministic
//Phaneuf and Victor
//August 2018



/*
 * Copyright (C) 2010 Dynare Team
 *
 * This file is part of Dynare.
 *
 * Dynare is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Dynare is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 */



var C I K Kh Z L Y profit w wr infl pr int rk lam mu mc x1 x2 f1 f2 vp dY pmu dmpu mrs wmu dwmu mpl lwedge wedge1 wedge2 vw utc utn Vc Vn V welfa A einvs;

% MU of consumption; consumption; return on capital; utilization; multiplier on accumulation;
% investment; interest rate; inflation; reset wage; auxiliary variables f1 and f2;
% capital services; real marginal cost; price dispersion; gross output; labor;
% intermediate inputs; reset price; auxiliary variables x1 and x2; wage;
% output; capital; intertemporal preference shock; intratemporal preference shock;
% productivity; monetary shock; investment-specific shock

varexo uA ur uinvs;

% shock to intertemporal preference; intratemporal preference; productivity; monetary policy; investment-specific

parameters beta b gamma1 gamma2 kappa delta theta sigma xiw xip zetaw zetap chi eta pistar alpha rhoi alphapi alphay ga gi gup rhoA suA rhoinvs suinvs sur F ls ys ks cs invss lams x1s x2s f1s f2s ints vps ws wrs mcs vws As;

% discount factor; habit formation; utilization cost; investment adjustment cost;
% depreciation; inflation target; elasticity of sub labor; inverse Frisch; labor disutility;
% calvo wages; indexation wages; capital share; intermediate share; fixed cost;
% elasticity of sub goods; calvo prices; indexation prices; TR inflation; 
% TR output; TR smoothing; AR shocks; SD shocks; ss interest rate; ss output 

load param_main_determ;
set_param_value('beta',beta);
set_param_value('b',b);
set_param_value('gamma1',gamma1);
set_param_value('gamma2',gamma2);
set_param_value('kappa',kappa);
set_param_value('delta',delta);
set_param_value('pistar',pistar);
set_param_value('sigma',sigma);
set_param_value('chi',chi);
set_param_value('eta',eta);
set_param_value('xiw',xiw);
set_param_value('zetaw',zetaw);
set_param_value('alpha',alpha);
set_param_value('F',F);
set_param_value('theta',theta);
set_param_value('xip',xip);
set_param_value('zetap',zetap);
set_param_value('alphapi',alphapi);
set_param_value('alphay',alphay);
set_param_value('rhoA',rhoA);
set_param_value('rhoi',rhoi)
set_param_value('rhoinvs',rhoinvs);
set_param_value('suA',suA);
set_param_value('sur',sur);
set_param_value('suinvs',suinvs);
set_param_value('gup',gup);
set_param_value('gi',gi);
set_param_value('ga',ga);
set_param_value('ls',ls);
set_param_value('ys',ys);
set_param_value('cs',cs);
set_param_value('ks',ks);
set_param_value('invss',invss);
set_param_value('lams',lams);
set_param_value('x1s',x1s);
set_param_value('x2s',x2s);
set_param_value('f1s',f1s);
set_param_value('f2s',f2s);
set_param_value('ints',ints);
set_param_value('vps',vps);
set_param_value('ws',ws);
set_param_value('wrs',wrs);
set_param_value('lams',lams);
set_param_value('mcs',mcs);
set_param_value('vws',vws);
set_param_value('As',As);



model;

% (1) marginal utility of consumption
exp(lam) = (exp(C)-b*gup^(-1)*exp(C(-1)))^(-1) - beta*b*(gup*exp(C(+1)) - b*exp(C))^(-1);

% (2) FOC for utilization
exp(rk) = (1/exp(einvs))*(gamma1 + gamma2*(exp(Z) - 1));

% (3) investment FOC
exp(lam) = exp(mu)*exp(einvs)*(1 - (kappa/2)*(exp(I)/exp(I(-1))*gup - gup)^2 - kappa*(exp(I)/exp(I(-1))*gup - gup)*(exp(I)/exp(I(-1)))*gup) + beta*gup^(-1)*exp(mu(+1))*kappa*(exp(I(+1))/exp(I)*gup - gup)*(exp(I(+1))/exp(I)*gup)^2;

% (4) capital FOC
gi*gup*exp(mu) = beta*exp(lam(+1))*(exp(rk(+1))*exp(Z(+1)) -exp(einvs(+1))^(-1)*(gamma1*(exp(Z(+1)) - 1) + (gamma2/2)*(exp(Z(+1)) - 1)^2)) + beta*(1-delta)*exp(mu(+1));

% (5) bonds FOC
exp(lam) = beta*gup^(-1)*(1+int)*exp(infl(+1))^(-1)*exp(lam(+1));

% (6) Reset wage
exp(wr) = (sigma/(sigma - 1))*exp(f1)/exp(f2);


% (7) Auxiliary f1
exp(f1) = eta*(exp(wr)/exp(w))^(-sigma*(1+chi))*exp(L)^(1+chi) + beta*xiw*((exp(wr)/exp(wr(+1)))*(exp(infl)^(zetaw)/exp(infl(+1))))^(-sigma*(1+chi))*gup^(sigma*(1+chi))*exp(f1(+1));

% (8) Auxiliary f2
exp(f2) = exp(lam)*(exp(wr)/exp(w))^(-sigma)*exp(L) + beta*xiw*(exp(wr)/exp(wr(+1)))^(-sigma)*(exp(infl)^(zetaw)/exp(infl(+1)))^(1-sigma)*gup^(sigma-1)*exp(f2(+1));

% (9) Capital services demand
exp(Kh) = gup*gi*alpha*(exp(mc)/exp(rk))*(exp(vp)*exp(Y) + F);

% (10) Labor demand
exp(L) = (1-alpha)*(exp(mc)/exp(w))*(exp(vp)*exp(Y) + F);

% (12) Reset price
exp(pr) = (theta/(theta-1))*(exp(x1)/exp(x2));

% (13) Auxiliary x1
exp(x1) = exp(lam)*exp(mc)*exp(Y) + xip*beta*exp(infl(+1))^(theta)*exp(infl)^(-zetap*theta)*exp(x1(+1));

% (14) Auxiliary x2
exp(x2) = exp(lam)*exp(Y) + xip*beta*exp(infl(+1))^(theta-1)*exp(infl)^(zetap*(1-theta))*exp(x2(+1));

% (19) Accounting
exp(Y) = exp(C) + exp(I) + (gamma1*(exp(Z)-1) + (gamma2/2)*(exp(Z)-1)^2)*exp(K(-1))*gup^(-1)*gi^(-1);


% (15) Price evolution
1 = xip*exp(infl)^(theta-1)*exp(infl(-1))^(zetap*(1-theta)) + (1-xip)*exp(pr)^(1-theta);


% (16) Wage evolution
exp(w)^(1-sigma) = xiw*exp(w(-1))^(1-sigma)*gup^(sigma-1)*exp(infl)^(sigma-1)*exp(infl(-1))^(zetaw*(1-sigma)) + (1-xiw)*exp(wr)^(1-sigma);


% (18) Aggregate production
exp(vp)*exp(Y) = exp(A)*exp(Kh)^alpha*exp(L)^(1-alpha)*gup^(-alpha)*gi^(-alpha) - F;


% (20) Capital accumulation
exp(K) = exp(einvs)*(1-(kappa/2)*(exp(I)/exp(I(-1))*gup - gup)^2)*exp(I) + (1-delta)*gup^(-1)*gi^(-1)*exp(K(-1));


% (22) Capital services
exp(Kh) = exp(Z)*exp(K(-1));

% (23) Price dispersion
exp(vp) = (1-xip)*exp(pr)^(-theta) + xip*exp(infl)^(theta)*exp(infl(-1))^(-zetap*theta)*exp(vp(-1));

% (21) Taylor rule
((1+int)/(1+ints)) = ((exp(infl)/pistar)^(alphapi)*(exp(Y)/exp(Y(-1)))^(alphay))^(1-rhoi)*( (1+int(-1))/(1+ints) )^(rhoi)*exp(ur);

% (26) Productivity shock
exp(A) = exp(A(-1))^(rhoA)*As^(1-rhoA)*exp(uA);

% (28) Investment-specific shock
exp(einvs) = exp(einvs(-1))^(rhoinvs)*exp(uinvs);

% (33) Output growth
dY = Y - Y(-1) + log(gup);

% (34) Price Markup
pmu = -mc; 

% (35) First difference of price markup
dmpu = pmu-pmu(-1);


% (36) Marginal rate of substitution
mrs = log(eta) + chi*L - lam;

% wage markup
wmu = w - mrs;

% (38) First difference of wage markup
dwmu=wmu-wmu(-1);

mpl = log(1-alpha) +  A +alpha*Kh + ((1-alpha)-1)*L + alpha*log(gup) + alpha*log(gi);

% (40) Labor wedge
lwedge = mpl-mrs;

% (41) Wedge 1
wedge1 = mrs - w;

% (42) Wedge 2
wedge2 = mpl - w;


% (29) Wage dispersion
exp(vw) = (1-xiw)*(exp(wr)/exp(w))^(-sigma*(1+chi)) + xiw*((exp(w(-1))/exp(w))*gup^(-1)*(exp(infl(-1))^(zetaw)/exp(infl)))^(-sigma*(1+chi))*exp(vw(-1));

% (30) Utility from consumption
utc = log(exp(C) - b*gup^(-1)*exp(C(-1)));

% (31) Utility from labor
utn = -eta*(exp(L)^(1+chi)/(1+chi))*exp(vw);

% (32) Welfare from consumption
Vc = utc + beta*Vc(+1);

% (33) Welfare from labor
Vn = utn + beta*Vn(+1);

% (34) Total welfare
V = Vc + Vn + welfa;

welfa =beta*log(gup)/((1-beta)^2);

% (32) Profit
profit = exp(Y) - exp(w)*exp(L) - exp(rk)*exp(Kh)*gup^(-1)*gi^(-1);

end;

initval;

C = log(cs);
Y = log(ys);
K = log(ks);
L = log(ls);
I = log(invss);
Kh = log(ks);
vp = log(vps);
Z = 0;
int = ints;
infl = log(pistar);
pr = log(pistar);
w = log(ws);
wr = log(wrs);
f1 = log(f1s);
f2 = log(f2s);
x1 = log(x1s);
x2 = log(x2s);
rk = log(gamma1);
lam = log(lams);
mu = log(lams);
mc = log(mcs);

vw = log(vws);
utc = log(cs - b*gup^(-1)*cs);
utn = -eta*vws*(ls^(1+chi)/(1+chi));
Vn = (1/(1-beta))*(-eta*vws*(ls^(1+chi)/(1+chi)));
Vc = (1/(1-beta))*(log(cs - b*gup^(-1)*cs));
V = (1/(1-beta))*(-eta*vws*(ls^(1+chi)/(1+chi))) + (1/(1-beta*gup))*(log(cs - b*gup^(-1)*cs)) + (beta*log(gup))/((1-beta)^2);
profit = 0;

end;

steady;
shocks;

var uA = suA^2;
var ur = sur^2;
var uinvs = suinvs^2;
end;

stoch_simul(order=2,irf=0,nograph,pruning,noprint,ar=0);