%November 2018

% Long-Run Inflation and the Distorting Effects of Sticky Wages and 
%Technical ChangeLong-Run Inflation and the Distorting Effects of 
%Sticky Wages and Technical Change

%%%%%%%%%%%
% TABLE 2 % 
%%%%%%%%%%%

clear all
close all
clc
global ga alpha gi mcs xiw sigma pistar delta eta b beta ys chi

%% parameters
for ST=0:1:1  %(ST=1:stochastic trend; ST=0:deterministic trend)
    SP=1;     %(SP=1:sticky price; SP=0:flexible price)
    SW=1;     %(SW=1:sticky wage; SP=0:flexible wage)
    beta = 0.99; % discount factor
    b = 0.8; % habit formation
    gamma2 = 0.05; % % utilization cost
    kappa = 3; % investment adjustment cost
    delta = 0.025; % depreciation rate
    theta = 4; % elasticity substitution differentated goods
    sigma=4;   % elasticity substitution differentiated skills
    zetap = 0; % indexation price
    zetaw = 0; % indexation wage
    chi = 1; % Frisch elasticity
    eta = 6; % labor disutility
    pistar = 1.008675; % steady state gross inflation
    alpha = 1/3; % Cobb-Douglas parameter
    rhoi = 0.8; % TR smoothing
    alphapi = 1.5; % TR inflation
    alphay = 0.2; % TR output growth

    % shock parameters
    gid = 1.00472; % desired growth of IST
    gyd = 1.005712; % desired growth of output
    gad = (gyd/(gid^(alpha/(1-alpha))))^(1-alpha);
    ga = gad; % growth of neutral prod
    gi = gid; % growth of IST
    gup = ga^(1/(1-alpha))*gi^(alpha/(1-alpha)); % growth of upsilon


    if SP==1
        xip = 0.55;
    else
        xip=0;
    end

    if SW==1
        xiw = 0.66;
    else
        xiw=0;
    end

    suA=0.003;
    suinvs=0.003; 
    sur=0.003;

    if ST==1 
        rhoA = 0; % no-stationary TFP
        rhoinvs = 0; % no-stationary IST
        run solve_for_steady_state
        save param_main beta b gamma1 gamma2 kappa delta theta sigma xiw xip zetaw zetap chi eta pistar alpha rhoi alphapi alphay ga gi gup rhoA suA rhoinvs suinvs sur F ls ys ks cs invss lams x1s x2s f1s f2s ints vps ws wrs lams mcs vws
        dynare base_stochastic_short noclearall nolog
        shocks_size_stoch
        shocks_baseline=[ga gi sur suinvs suA];
        save Shock shocks_baseline
    else
        %random walk process for IST and neutral technology
        rhoA = 0.95; % stationary TFP
        rhoinvs = 0.72; % stationary IST
        run solve_for_steady_state
        save param_main beta b gamma1 gamma2 kappa delta theta sigma xiw xip zetaw zetap chi eta pistar alpha rhoi alphapi alphay ga gi gup rhoA suA rhoinvs suinvs sur F ls ys ks cs invss lams x1s x2s f1s f2s ints vps ws wrs lams mcs vws
        dynare base_deterministic_short noclearall nolog
        shocks_size_determ
        shocks_deterministic=[ga gi sur suinvs suA]; 
    end
end
%% TABLE 2

TABLE2=[shocks_baseline;shocks_deterministic]

